userFlaviencancel
reporust_rebootcancel

8,306 Commits over 1,035 Days - 0.33cph!

4 Hours Ago
merge from scrapking_batching_fix
Today
Fixed more blocks not batching - Jungle ramps, spiral, L and U stairs - Container roofl ines - Frontier square floor details
Today
Updated the test to catch more stuff
Today
Fixed adobe woodbeams not batching (forgot to add the RendererBatch when implementing wallpaper)
Today
Fixed the rest of the stuff not batching: - Crypt stairs and spiral landings - Adobe roof lines and low wall corners - Brick roofs - Twig roofs and roof lines - Brutalist triangle spiral landing
Today
Fixed gingerbread building skin not batching at all
Today
Fixed HQM walls, frames and spiral stairs LOD0 blocks not batching
Today
Fixed none of the ramps batching across all skins
Today
Fixed space station roofs and wall corners not batching
Today
Fixed frontier building skin not batching at all: - set read/write true on all FBXs - set AllowSubmeshes to true on the ramp prefabs
Today
Added test checking building skin meshes are all batchable 87 are failing
Today
merge from scrapking_batching_fix
Today
Fixed scrap king building skin not batching: - set AllowSubmeshes to true on all prefabs - set wall frame and floor triangle frame fbx as readable
3 Days Ago
Phrase update
3 Days Ago
merge from phrases_oct26
3 Days Ago
Fixes time phrase dupes Fixed apartment complex clerk saying a phone line
3 Days Ago
merge from storepage_oct26
3 Days Ago
Store analytics fixes
3 Days Ago
Scrap king store page wip
3 Days Ago
merge from storepage_oct26
3 Days Ago
Updated sunburn media
3 Days Ago
Append hash to uploaded store media URLs, so an updated image gets a different URL
4 Days Ago
▌▊█▅▌▄ ▉▄▄▄ ▌▅▇█▋▋▊▌▇▉▄▄▍▌▋▍
4 Days Ago
▇▇▋▍▇▅ ▅▉▌▋ ▄▇▊▍▄▅▅▆▇▅▍▌▋█▊▆
4 Days Ago
▋▄▄▊ ▍▆▊ ▄▋▇▇▉▍█ ▇▉ ▋▉▆▋ ▋▉ ▉▅▉ ▊▉▆▇█▍ ▄▉▄ ▇▍▅▇ ▌▋▇ ▋▊▉ ▋▆▉ ▆▉▆▇
4 Days Ago
▋█▊▆▄ ▉▋▄ ▉▊▌ ▍▊▇▍▆ ▍▇ ▆▄ ▉▄▆█▇ ▇▌▍▋▌▆▉ ▋▄▊▌█▄ █▊▋▅▉▇▊█ ▌▆▇ ▍▅▉█▍▆▊▆
4 Days Ago
▌▋▊▋▍▉ ▌▍▉▌█ ▋▅▉▍ ▇▅ ▉▅▉▅ ▆███▊█▅▋▊█▄▊▄ ▊▅▇▋ ▊▌▄▄▊▋ ▉▆ ▆▊█ ▊█▉█ ▌▆ ▉▆▅ ▆▇▅▊▆▍█▇▅▄ ▌▌▍▇ ▍▆█ ▅▊ ▊▍▆▇▌▋▄▅▍ ▉▌ ▋▅▍▅▉▆▋▇▋▊▇ ▅▅▅▋▊▋▅▉▅█▅ ▍▉▆▄▍▇
4 Days Ago
Fixed UI_Store formatting
4 Days Ago
merge from store_notif_fix
4 Days Ago
Debug convar to reset the NEW notif
4 Days Ago
Fixed store NEW notification when skins are released
4 Days Ago
Reduced the range of 62 lights in the caboose from 80 to 15 meters (they have a 1m range) Saves aroud 0.1ms when close to outpost with the caboose switched on S2P outpost
4 Days Ago
merge from piemenu_icons_stacked_fix
4 Days Ago
Fix attempt for pie menu icons stacked top right and emojis offset
4 Days Ago
Fixed limited store grid NRE
4 Days Ago
merge from store_gridnre_fix
4 Days Ago
Deleted 25 rocks placed 2.5km under the terrain in the excavator monument S2P excavator
4 Days Ago
Restored codegen
4 Days Ago
Preload 324 cow and sheep sounds like the other animals Avoids a ~1.2ms hitch the first time each clip plays, memory impact is only around 3MB
4 Days Ago
▇▅▅▊▋▇ ▉▉▇▌ ▊▆▇▊▅▍▉▆▉▄▋▇▆▆▉▊▊▄▇▅▇▋▉▍█▉
4 Days Ago
▌▌██▇█ ▄ ▄▆▉▍ █▊▅█ ▆▅▊▉ ▊▊▅▄▌█ ▄▌▇▄▇▍ █▅▍▅▉ ▇▌▊ ▋▍▍█▄▇█▍▌▉
5 Days Ago
merge from more_lod_optims
5 Days Ago
Use a hashset for the combined mesh lookup from 169597, Contains was slow on big ass bases
5 Days Ago
Fixed LODs showing their level a second time after being enabled, was tooking batched blocks out of their batch and back in for nothing
5 Days Ago
Fixed opening a double door rebuilding the batched walls around it, the door frame now stays batched while the door swings Regression from 169567
5 Days Ago
merge from more_lod_optims
5 Days Ago
Fixed pooled blocks staying unbatched, their LOD component asked to batch them before their RendererBatch component was enabled
5 Days Ago
Gamepad icon for the gamepad section in the settings
5 Days Ago
Batched meshes only recalculate UV0 distribution metric, UV1 are for lightmaps which we don't use Editor profiling, walking around the same big base: RendererCell.ApplyBatches ~4.5ms -> ~3.1ms
5 Days Ago
Optimised RendererGroup invalidation, only the combined mesh holding the block is switched back to separate renderers Editor profiling, walking around the same big base: slowest LOD switch ~2.5ms -> ~1ms